"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidPassword = exports.PASSWORD_VALIDATION_REGEX = void 0;
const getValidatorFn_js_1 = require("../utils/getValidatorFn.js");
/**
 * Regex for validating passwords, which must meet the following conditions:
 * - Contains at least one lowercase letter.
 * - Contains at least one uppercase letter.
 * - Contains at least one number.
 * - Contains at least one of `!`, `@`, `#`, `$`, `%`, `^`, `&`, and/or `*`.
 * - Is at least 6 characters long, and no more than 250 characters long.
 */
exports.PASSWORD_VALIDATION_REGEX = /^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)(?=.*[!@#$%^&*])[A-Za-z\d!@#$%^&*]{6,250}$/;
/**
 * Returns `true` if `value` is a valid password.
 * > See {@link PASSWORD_VALIDATION_REGEX} for validation requirements.
 */
exports.isValidPassword = (0, getValidatorFn_js_1.getValidatorFn)(exports.PASSWORD_VALIDATION_REGEX);
