"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidStreetAddress = exports.STREET_ADDRESS_VALIDATION_REGEX = void 0;
const getValidatorFn_js_1 = require("../utils/getValidatorFn.js");
/**
 * Regex for validating street-address strings (line 1 or line 2).
 *
 * ### Pattern Notes
 *
 * - `(?!\s*$)`      — Prevents the string from being empty.
 * - `(?=.{5,100}$)` — Requires the string to be between 5 and 100 characters long.
 * - `(?=.*\d)`      — Requires the string to contain at least one digit.
 */
exports.STREET_ADDRESS_VALIDATION_REGEX = /^(?!\s*$)(?=.{5,100}$)(?=.*\d)[\p{Script=Latin}\s\d'.:,#-]+$/iu;
/**
 * Returns `true` if `value` is a valid street address (line 1 or line 2).
 */
exports.isValidStreetAddress = (0, getValidatorFn_js_1.getValidatorFn)(exports.STREET_ADDRESS_VALIDATION_REGEX);
